@@ -35,21 +35,22 @@
 '''
 Differential equations for Brian models.
 '''
-#from scipy.weave import blitz
 from operator import isSequenceType
 import types
 from units import *
 from stdunits import *
 from inspection import *
 from scipy import exp
-from scipy import weave
+try:
+    import weave
+except ImportError:
+    from scipy import weave
 from globalprefs import *
 import re
 import inspect
 import optimiser
 import warnings
 import uuid
-import numpy
 from numpy import zeros, ones
 import numpy
 from log import *
@@ -184,6 +185,9 @@ class Equations(object):
         self._frozen = False # True if all units and parameters are gone
         self._prepared = False
 
+        if expr is None:
+            expr = ''
+
         if not isinstance(expr, str): # assume it is a sequence of Equations objects
             for eqs in expr:
                 if not isinstance(eqs, Equations):
@@ -997,6 +1001,7 @@ def _load_Equations_from_pickle(eqs, cls):
                 replaceufunc(v)
     replaceufunc(eqs.__dict__)
     eqs.__class__ = cls
+    eqs._prepared = False
     eqs.prepare()
     return eqs
 
