@@ -7,7 +7,10 @@ from ...equations import Equations
 from ...globalprefs import get_global_preference
 from ...log import log_warn
 from expressions import *
-from scipy import weave
+try:
+    import weave
+except ImportError:
+    from scipy import weave
 from c_support_code import *
 
 __all__ = ['generate_c_threshold', 'generate_python_threshold',
@@ -63,6 +66,10 @@ class PythonThreshold(Threshold):
         self._ns['t'] = P.clock._t
         return eval(self._compiled_code, self._ns).nonzero()[0]
 
+    def __repr__(self):
+        return 'PythonThreshold(%r)' % self._inputcode
+
+    __str__ = __repr__
 
 class CThreshold(Threshold):
     def __init__(self, inputcode, level=0):
@@ -100,3 +107,7 @@ class CThreshold(Threshold):
             return self.__call__(P)
         return _spikes[0:_numspikes]
 
+    def __repr__(self):
+        return 'CThreshold(%r)' % self._inputcode
+
+    __str__ = __repr__
\ No newline at end of file
