@@ -1,7 +1,10 @@
 #import brian_no_units
 from brian import *
 from brian import optimiser
-from scipy import weave
+try:
+    import weave
+except ImportError:
+    from scipy import weave
 try:
     import pycuda
     import pycuda.autoinit as autoinit
@@ -212,7 +215,7 @@ class GPUNeuronGroup(NeuronGroup):
 
 if __name__ == '__main__':
 
-    from brian.experimental.ccodegen import AutoCompiledNonlinearStateUpdater
+    #from brian.experimental.ccodegen import AutoCompiledNonlinearStateUpdater
     set_global_preferences(usecodegen=False)
 
     #duration = 10*second
