@@ -7,6 +7,7 @@ g = PoissonGroup(100, 100*Hz)
 #g = SpikeGeneratorGroup(1, [(0,t*ms) for t in range(int(runtime/defaultclock.dt))])
 
 Maer = AERSpikeMonitor(g, './dummy.aedat')
+M = SpikeMonitor(g)
 
 
 run(100*ms)
@@ -15,11 +16,11 @@ Maer.close_file()
 
 
 addr, timestamps = load_AER('./dummy.aedat')
-if len(addr) == len(M.spikes):
+if len(addr) == M.nspikes:
     print 'looks good'
 else:
     print 'glub'
-    print 'addr, M.spikes',len(addr),len(M.spikes)
+    print 'addr, M.spikes',len(addr),M.nspikes
 
 # Check for NewSpikeGeneratorGroup
 N = max(addr)
