@@ -7,4 +7,4 @@ from drnl import DRNL
 from dcgc import DCGC
 from fractionaldelay import *
 #from zilany import ZILANY
-from tan_carney import TanCarney
\ No newline at end of file
+from tan_carney import *
\ No newline at end of file
