@@ -259,6 +259,14 @@ class Network(object):
         for obj in objs:
             if isinstance(obj, (NeuronGroup, Connection, NetworkOperation)):
                 self._added_objects = [o for o in self._added_objects if o is not obj]
+                if isinstance(obj, NeuronGroup):
+                    self.groups = [o for o in self.groups if o is not obj]
+                if isinstance(obj, Connection):
+                    self.connections = [o for o in self.connections if o is not obj]
+                if isinstance(obj, NetworkOperation):
+                    self._all_operations = [o for o in self._all_operations if o is not obj]
+                    self._operations_dict[obj.when] = [o for o in self._operations_dict[obj.when]
+                                                       if o is not obj]
             elif isSequenceType(obj):
                 for o in obj:
                     self.remove(o, unprepare=False)
@@ -319,12 +327,13 @@ class Network(object):
 
         # Gather connections with identical subgroups
         # 'subgroups' maps subgroups to connections (initialize with immutable object (not [])!)
-        subgroups = dict.fromkeys([(C.source, C.delay) for C in self.connections], None)
+        # Use ids of the objects here, to avoid hashing problems
+        subgroups = dict.fromkeys([(id(C.source), id(C.delay)) for C in self.connections], None)
         for C in self.connections:
-            if subgroups[(C.source, C.delay)] == None:
-                subgroups[(C.source, C.delay)] = [C]
+            if subgroups[(id(C.source), id(C.delay))] is None:
+                subgroups[(id(C.source), id(C.delay))] = [C]
             else:
-                subgroups[(C.source, C.delay)].append(C)
+                subgroups[(id(C.source), id(C.delay))].append(C)
         self.connections = subgroups.values()
         cons = self.connections # just for readability
         for i in range(len(cons)):
