@@ -32,12 +32,17 @@
 # knowledge of the CeCILL license and that you accept its terms.
 # ----------------------------------------------------------------------------------
 # 
+from brian.stateupdater import LazyStateUpdater
 '''
 Neuron groups
 '''
 __all__ = ['NeuronGroup', 'linked_var']
 
 from numpy import *
+try:
+    import weave
+except ImportError:
+    from scipy import weave
 from scipy import rand, linalg, random
 from numpy.random import exponential, randint
 import copy
@@ -62,6 +67,7 @@ from base import *
 from group import *
 from threshold import select_threshold
 from collections import defaultdict
+from log import log_info
 
 timedarray = None # ugly hack: import this module when it is needed, can't do it here because of order of imports
 network = None # ugly hack: import this module when it is needed, can't do it here because of order of imports
@@ -167,6 +173,8 @@ class NeuronGroup(magic.InstanceTracker, ObjectContainer, Group):
         string, giving the name of a state variable in the group. In the case
         of these variable refractory periods, you should specify
         ``min_refractory`` (optional) and ``max_refractory`` (required).
+    ``level=0``
+        See :class:`Equations` for details.
     ``clock``
         A clock to use for scheduling this :class:`NeuronGroup`, if omitted the
         default clock will be used.
@@ -254,6 +262,13 @@ class NeuronGroup(magic.InstanceTracker, ObjectContainer, Group):
         Initializes the group.
         '''
 
+        self._useweave = get_global_preference('useweave')
+        if self._useweave:
+            self._cpp_compiler = get_global_preference('weavecompiler')
+            self._extra_compile_args = ['-O3']
+            if self._cpp_compiler == 'gcc':
+                self._extra_compile_args += get_global_preference('gcc_options')
+
         self._spiking = True # by default, produces spikes
         if bup.use_units: # one additional frame level induced by the decorator
             level += 1
@@ -287,27 +302,32 @@ class NeuronGroup(magic.InstanceTracker, ObjectContainer, Group):
             self._state_updater = model # Update mechanism
             self._all_units = defaultdict()
         elif isinstance(model, Equations):
-            self._eqs = model
-            if (init == None) and (model._units == {}):
-                raise AttributeError, "The group must be initialized."
-            self._state_updater, var_names = magic_state_updater(model, clock=clock, order=order,
-                                                                 check_units=unit_checking, implicit=implicit,
-                                                                 compile=compile, freeze=freeze,
-                                                                 method=method)
-            Group.__init__(self, model, N, unit_checking=unit_checking)
-            self._all_units = model._units
-            # Converts S0 from dictionary to tuple
-            if self._S0 == None: # No initialization: 0 with units
-                S0 = {}
+            if len(model) == 0:
+                self._eqs = model
+                self._state_updater = LazyStateUpdater(0)
+                self._all_units = defaultdict()
             else:
-                S0 = self._S0.copy()
-            # Fill missing units
-            for key, value in model._units.iteritems():
-                if not key in S0:
-                    S0[key] = 0 * value
-            self._S0 = [0] * len(var_names)
-            for var, i in zip(var_names, count()):
-                self._S0[i] = S0[var]
+                self._eqs = model
+                if (init == None) and (model._units == {}):
+                    raise AttributeError, "The group must be initialized."
+                self._state_updater, var_names = magic_state_updater(model, clock=clock, order=order,
+                                                                     check_units=unit_checking, implicit=implicit,
+                                                                     compile=compile, freeze=freeze,
+                                                                     method=method)
+                Group.__init__(self, model, N, unit_checking=unit_checking)
+                self._all_units = model._units
+                # Converts S0 from dictionary to tuple
+                if self._S0 == None: # No initialization: 0 with units
+                    S0 = {}
+                else:
+                    S0 = self._S0.copy()
+                # Fill missing units
+                for key, value in model._units.iteritems():
+                    if not key in S0:
+                        S0[key] = 0 * value
+                self._S0 = [0] * len(var_names)
+                for var, i in zip(var_names, count()):
+                    self._S0[i] = S0[var]
         else:
             raise TypeError, "StateUpdater must be specified at initialization."
         # TODO: remove temporary unit hack, this makes all state variables dimensionless if no units are specified
@@ -461,7 +481,7 @@ class NeuronGroup(magic.InstanceTracker, ObjectContainer, Group):
         '''
         if self._owner is self:
             if states:
-                if self._S0 is not None:
+                if self._S0 is not None and self._state_updater is not None:
                     for i in range(len(self._state_updater)):
                         self._S[i, :] = self._S0[i]
                 else:
@@ -478,6 +498,8 @@ class NeuronGroup(magic.InstanceTracker, ObjectContainer, Group):
             spikes = self._threshold(self) # get spikes
             if not isinstance(spikes, numpy.ndarray):
                 spikes = array(spikes, dtype=int)
+            if not spikes.flags.contiguous:
+                spikes = array(spikes)
             if self._use_next_allowed_spiketime_refractoriness:
                 spikes = spikes[self._next_allowed_spiketime[spikes] <= self.clock._t]
                 if self._variable_refractory_time:
@@ -598,18 +620,79 @@ class NeuronGroup(magic.InstanceTracker, ObjectContainer, Group):
 
     def __repr__(self):
         if self._owner == self:
-            return 'Group of ' + str(len(self)) + ' neurons'
+            return '%s(%d, model=%s, threshold=%s, reset=%s)' % (self.__class__.__name__,
+                                                                 len(self),
+                                                                 repr(self._state_updater),
+                                                                 repr(self._threshold),
+                                                                 repr(self._resetfun))
         else:
-            return 'Subgroup of ' + str(len(self)) + ' neurons'
+            return '<Size %d subgroup of %s>' % (len(self), repr(self._owner))
+
+    def __str__(self):
+        if self._owner == self:
+            return '%s of %d neurons' % (self.__class__.__name__, len(self))
+        else:
+            return 'Size %d subgroup of %s' % (len(self), self.__class__.__name__)
+                 
 
     def __setattr__(self, name, val):
         global timedarray
         if timedarray is None:
             import timedarray
+
+        # make sure we are only handing resolved names        
+        if hasattr(self, '_eqs') and name in self._eqs._alias:
+            self.__setattr__(self._eqs._alias[name], val)
+            return
+
         if isinstance(val, timedarray.TimedArray):
-            self.set_var_by_array(name, val)
+            self.set_var_by_array(name, val)        
+        elif hasattr(self, 'staticvars') and name in self.staticvars:
+            raise ValueError("Cannot assign static variable "+name)            
         elif isinstance(val, LinkedVar):
             self.link_var(name, val.source, val.var, val.func, val.when, val.clock)
+        elif hasattr(val,"synapses") and not isinstance(val,Equations): # a synaptic variable
+            # This above is a hack because we can't import SynapticVariable (infinite recursion)
+            S=val.synapses
+            if S.target!=self:
+                raise AttributeError,"Can only link a synaptic variable to the target group"
+            global network
+            if network is None:
+                import network
+            selfarr = self.state_(name)
+            s_name = val.name
+
+            #Faster version using weave
+            if self._useweave:
+                log_info('brian.neurongroup',
+                         'Using weave for lumped variable.')
+                compiler = self._cpp_compiler
+                extra_args = self._extra_compile_args
+
+                @network.network_operation(clock=S.clock)
+                def update_link_var():
+                    s_state = S.state_(s_name)
+                    code = '''
+                    for (int i=0; i<N; i++) {
+                        summed[postsynaptic[i]] += s_state[i];
+                    }
+                    '''
+                    summed = zeros_like(selfarr)
+                    postsynaptic = S.postsynaptic.data
+                    N = len(postsynaptic)
+                    weave.inline(code, ['summed', 'N', 's_state',
+                                        'postsynaptic'],
+                                 compiler=compiler,
+                                 extra_compile_args=extra_args)
+                    selfarr[:] = summed
+            else:
+                @network.network_operation(clock=S.clock)
+                def update_link_var():
+                    s_state = S.state_(s_name)
+                    selfarr[:] = array([sum(s_state[post_syns.data]) for
+                                        post_syns in S.synapses_post])
+
+            self._owner.contained_objects.append(update_link_var)
         else:
             Group.__setattr__(self, name, val)
 
