@@ -145,7 +145,7 @@ class STDP(NetworkOperation):
         dA_pre/dt  = -A_pre/tau_pre   : 1
         dA_post/dt = -A_post/tau_post : 1
         """
-        stdp = STDP(synapses, eqs=eqs_stdp, pre='A_pre+=delta_A_pre; w+=A_post',
+        stdp = STDP(C, eqs=eqs_stdp, pre='A_pre+=delta_A_pre; w+=A_post',
                     post='A_post+=delta_A_post; w+=A_pre', wmax=gmax)
 
     **STDP variables**
@@ -223,6 +223,13 @@ class STDP(NetworkOperation):
 
         # additional dependencies are used to ensure that if there are multiple
         # pre/post separated equations they are grouped together as one
+        #
+        # We should replace with this code here, in case there are no pre/post synaptic variables
+        #additional_deps =[]
+        #if len(vars_pre)>0:
+        #    additional_deps.append('__pre_deps='+'+'.join(vars_pre))
+        #if len(vars_post)>0:
+        #    additional_deps.append('__post_deps='+'+'.join(vars_post))
         additional_deps = ['__pre_deps='+'+'.join(vars_pre),
                            '__post_deps='+'+'.join(vars_post)]
         separated_equations = separate_equations(eqs_obj, additional_deps)
@@ -261,6 +268,8 @@ class STDP(NetworkOperation):
         post_namespace = namespace(post, level=level + 1)
         pre_namespace['clip'] = clip
         post_namespace['clip'] = clip
+        pre_namespace['Inf'] = Inf
+        post_namespace['Inf'] = Inf
         pre_namespace['enumerate'] = enumerate
         post_namespace['enumerate'] = enumerate
 
@@ -376,8 +385,12 @@ class STDP(NetworkOperation):
 
             # Bounds: add one line to pre/post code (clip(w,min,max,w))
             # or actual code? (rather than compiled string)
-            pre += '\n    w[_i,:]=clip(w[_i,:],%(min)e,%(max)e)' % {'min':wmin, 'max':wmax}
-            post += '\n    w[:,_i]=clip(w[:,_i],%(min)e,%(max)e)' % {'min':wmin, 'max':wmax}
+            if wmax==Inf:
+                pre += '\n    w[_i,:]=clip(w[_i,:],%(min)e,Inf)' % {'min':wmin}
+                post += '\n    w[:,_i]=clip(w[:,_i],%(min)e,Inf)' % {'min':wmin}
+            else:
+                pre += '\n    w[_i,:]=clip(w[_i,:],%(min)e,%(max)e)' % {'min':wmin, 'max':wmax}
+                post += '\n    w[:,_i]=clip(w[:,_i],%(min)e,%(max)e)' % {'min':wmin, 'max':wmax}
             log_debug('brian.stdp', 'PRE CODE:\n'+pre)
             log_debug('brian.stdp', 'POST CODE:\n'+post)
             # Compile code
@@ -390,7 +403,7 @@ class STDP(NetworkOperation):
                 delay_post = 0 * ms
             elif delay_pre is None:
                 delay_pre = connection_delay - delay_post
-                if delay_pre < 0 * ms: raise AttributeError, "Postsynaptic delay is too large"
+                if delay_pre < 0 * ms: raise AttributeError, "Presynaptic delay is too large"
             elif delay_post is None:
                 delay_post = connection_delay - delay_pre
                 if delay_post < 0 * ms: raise AttributeError, "Postsynaptic delay is too large"
