@@ -4,6 +4,7 @@ The Synapses class - see BEP-21
 import re
 import warnings
 from operator import isSequenceType
+import copy
 
 import numpy as np
 from numpy.random import binomial
@@ -31,6 +32,14 @@ except:
 
 __all__ = ['Synapses','invert_array']
 
+
+def _binomial_wrapper(n, p):
+    '''
+    A simple wrapper around numpy's binomial function for use in synaptic code.
+    '''
+    return np.random.binomial(np.array(n, dtype=int), p)
+
+
 class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
     '''Set of synapses between two neuron groups
     
@@ -90,13 +99,15 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
 
         Returns the synapse indexes correspond to i, which can be a tuple or a slice.
         If i is a tuple (m,n), m and n can be an integer, an array, a slice or a subgroup.
-    
-    The following usages are also possible for a Synapses object ``S``:
+
+    .. automethod:: save_connectivity
+        
+    *The following usages are also possible for a Synapses object ``S``*:
     
     ``len(S)``
         Returns the number of synapses in ``S``.
         
-    Attributes:
+    **Attributes**:
     
     ``delay``
         The presynaptic delays for all synapses (synapse->delay). If there are multiple
@@ -109,7 +120,7 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
         The time of last update of all synapses (synapse->last update). This
         only exists if there are dynamic synaptic variables.
     
-    Internal attributes:
+    *Internal attributes*:
     
     ``source``
         The source neuron group.
@@ -308,7 +319,7 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
         self.synapses_post=[DynamicArray1D(0,dtype=smallest_inttype(max_synapses)) for _ in range(len(self.target))]
 
         # Code generation
-        self._binomial = lambda n,p:np.random.binomial(np.array(n,dtype=int),p)
+        self._binomial = _binomial_wrapper
 
         self.contained_objects = []
         self.codes=[]
@@ -332,10 +343,6 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
             self.namespaces.append(_namespace)
             self.queues.append(SpikeQueue(self.target, self.synapses_post, self._delay_post, max_delay = max_delay))
 
-        self.queues_namespaces_codes = zip(self.queues,
-                                           self.namespaces,
-                                           self.codes)
-
         self.contained_objects+=self.queues
       
     def generate_code(self,code,level,direct=False,code_namespace=None):
@@ -371,6 +378,11 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
         _namespace = namespace(code, level = level + 1)
         if code_namespace is not None:
             _namespace.update(code_namespace)
+        # Explicitly set builtins to prevent adding all the builtins to the
+        # namespace (which leads to problems with pickling)
+        _namespace['__builtins__'] = {}
+        _namespace['len'] = len
+        _namespace['bool'] = np.bool
         _namespace['target'] = self.target # maybe we could save one indirection here
         _namespace['unique'] = np.unique
         _namespace['nonzero'] = np.nonzero
@@ -416,7 +428,22 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
             res = re.sub(r'\bn\b','len('+indices+')', res)
  
             return res
- 
+        # Check whether the pre/post-code writes to a pre-synaptic variable
+        # (which is not supported in general, with possibly several synapses
+        # sharing the same pre-synaptic cell)
+        for line in code.split('\n'):
+            split_line = line.split('=')
+            if len(split_line) > 1:
+                lhs = split_line[0]
+                if '_pre' in lhs:
+                    raise ValueError(('The synaptic code "%s" changes the '
+                                      'value of a pre-synaptic variable. This '
+                                      'is not allowed, since it can lead to '
+                                      'incorrect results if a pre-synaptic '
+                                      'neuron has more than one outgoing '
+                                      'connection. Please upgrade to Brian 2 '
+                                      'to get this functionality or re-write '
+                                      'your model.') % line)
         if direct: # direct update code, not caring about multiple accesses to postsynaptic variables
             code_str = '_post_neurons = _post[_synapses]\n'+update_code(code, '_synapses', '_post_neurons') + "\n"            
         else:
@@ -518,6 +545,41 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
         
         return compiled_code,_namespace
 
+    # Pickling support
+    def __getstate__(self):
+        # code objects cannot be pickled, we therefore delete them and later
+        # reconstruct them from the code strings (stored in the namespace)
+        state = copy.copy(self.__dict__)
+        state['codes'] = [None] * len(self.codes)
+        # We cannot pickle module objects and numpy is included as 'np'
+        for ns in state['namespaces']:
+            for k, v in ns.iteritems():
+                if v is np:
+                    ns[k] = None
+        return state
+
+    def __setstate__(self, state):
+        self.__dict__ = state
+        # Reconstruct the codes from the code string
+        for idx, (queue, namespace) in enumerate(zip(self.queues, self.namespaces)):
+            self.codes[idx] = compile(namespace['_original_code_string'],
+                                      "Synaptic code", "exec")
+            # I"m not quite sure why, but this seems to be necessary
+            for postsyn_var in self.target.var_index:
+                if isinstance(postsyn_var, str):
+                    namespace['_target_' + postsyn_var] = self.target.state_(postsyn_var)
+            for presyn_var in self.source.var_index:
+                if isinstance(presyn_var, str):
+                    namespace['_source_' + presyn_var] = self.source.state_(presyn_var)
+            namespace['target'] = self.target
+
+            # numpy array views don't survive pickling
+            queue.X_flat = queue.X.reshape(queue.X.size, )
+
+        # Re-compress the Synapses object (this also adds "np" to the namespaces)
+        self._iscompressed = False
+        self.compress()
+
     def __setitem__(self, key, value):
         '''
         Creates new synapses.
@@ -836,6 +898,14 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
         '''
         return neuron_indexes(x,self.target)
     
+    def uncompress(self):
+        # make the state matrix a dynamic array again
+        S = self._S
+        self._S = DynamicArray(S.shape)
+        self._S[:] = S
+        # now isn't compressed
+        self._iscompressed = False
+
     def compress(self):
         '''
         * Checks that the object is not empty.
@@ -932,18 +1002,19 @@ class Synapses(NeuronGroup): # This way we inherit a lot of useful stuff
     
     def save_connectivity(self, fn):
         '''
-        Saves the connectivity matrices and delays so that they can be reloaded afterwards. 
+        Saves the connectivity matrices and delays to a file ``fn``, so that they can be reloaded afterwards. 
         
         Notice that this only saves the connectivity, not the current state of the variables in the Synapses class. In fact, it is completely decoupled from the pre/post synaptic groups, and the models of the Synapses object.
         
-        Example: Say we want to save the connectivity of Synapses, and some other state of the network, say ``my_state''. We would simply do:
+        *Example*: Say we want to save the connectivity of Synapses, and some other state of the network, say ``my_state``. We would simply do::
         
-        array_to_save = synapses.my_state[:,:]
-        synapses.save_connectivity('./somefile')
 
-        new_synapses = Synapses(newgroup0, newgroup0, model = newmodel, pre = newpre, ...)
-        new_synapses.load_connectivity('./somefile')
-        new_synapses.my_state[:,:] = array_that_was_saved_and_then_reloaded
+            array_to_save = synapses.my_state[:,:]
+            synapses.save_connectivity('./somefile')
+            ...
+            new_synapses = Synapses(newgroup0, newgroup0, model = newmodel, pre = newpre, ...)
+            new_synapses.load_connectivity('./somefile')
+            new_synapses.my_state[:,:] = array_that_was_saved_and_then_reloaded
         
         Note: You have to deal with dynamical delays as you would with any other variable.
         '''
