@@ -13,48 +13,6 @@ def test():
     is a generator, as is a function which returns a list, or a generator
     function.
     
-    :class:`MultipleSpikeGeneratorGroup`
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    
-    Called as::
-    
-        MultipleSpikeGeneratorGroup(spiketimes[,clock])
-        
-    spiketimes is a list of spike containers, one for each neuron in the group.
-    The elements of the spike containers are spike times. Callable spike
-    containers are called when the group is reinitialised. If you provide
-    a generator rather than a callable object, reinitialising the group will
-    not reinitialise the generator. If the containers are numpy arrays units
-    will not be checked (times should be in seconds).
-    
-    So for example, the following will correspond to a group of 2 neurons, where
-    the first fires at times 0ms, 2ms and 5ms, and the second fires at times
-    1ms and 3ms::
-    
-        spiketimes = [[0*msecond, 2*msecond, 5*msecond],
-                      [1*msecond, 3*msecond]]
-        G = MultipleSpikeGeneratorGroup(spiketimes)
-    
-    You could do the same thing with generator functions (rather perversely in
-    this case)::
-    
-        def st1():
-            yield 0*msecond
-            yield 2*msecond
-            yield 5*msecond
-        def st2():
-            yield 1*msecond
-            yield 3*msecond
-        G = MultipleSpikeGeneratorGroup([st1(), st2()])
-
-    Note that if two or more spike times fall within the same dt, spikes will stack up
-    and come out one per dt until the stack is exhausted. A warning will be generated
-    if this happens.
-    
-    If a clock is provided, updates of the group will be synchronised with
-    that clock, otherwise the standard clock guessing procedure will be used
-    (see :func:`~brian.clock.guess_clock` in the :mod:`~brian.clock` module).
-    
     :class:`SpikeGeneratorGroup`
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     
@@ -127,63 +85,13 @@ def test():
         reinit_default_clock()
         return (spikes1, spikes2)
 
-    # check multiple spike generator group with lists
-    spiketimes = [[0 * msecond, 2 * msecond, 4 * msecond],
-                  [1 * msecond, 3 * msecond]]
-    spikes = mininet(MultipleSpikeGeneratorGroup, spiketimes)
-
     def test1(spikes):
         assert len(spikes) == 5
         i, t = zip(*spikes) # zip(*...) is the inverse of zip, so i is the ordered list of neurons that fired, and t is the ordered list of times
         assert i == (0, 1, 0, 1, 0) # check that the order of neuron firings is correct
         for s1, s2 in enumerate(t):
             assert is_approx_equal(s1 * msecond, s2) # the firing times are (0,1,2,3,4)ms
-    test1(spikes)
-
-    # check multiple spike generator group with arrays
-    # NOTE: Units are not checked, array has to be in seconds
-    spiketimes = [array([0.0, 0.002, 0.004]),
-                  array([0.001, 0.003])]
-    spikes = mininet(MultipleSpikeGeneratorGroup, spiketimes)
-    test1(spikes)
     
-    # multiple spike generator group with generator and period
-    def gen1():
-        yield 0 * msecond
-    def gen2():
-        yield 1 * msecond
-    spikes = mininet(MultipleSpikeGeneratorGroup, [gen1, gen2], period=2*ms)
-    test1(spikes)
-
-    # check that given a different clock it works as expected, wrap in a function to stop magic functions from
-    # picking up the clock objects we define here
-    def testwithclock():
-        spikes = mininet(MultipleSpikeGeneratorGroup, spiketimes, clock=Clock(dt=0.1 * msecond))
-        test1(spikes)
-        spikes = mininet(MultipleSpikeGeneratorGroup, spiketimes, clock=Clock(dt=2 * msecond))
-        assert len(spikes) == 5
-        i, t = zip(*spikes) # zip(*...) is the inverse of zip, so i is the ordered list of neurons that fired, and t is the ordered list of times
-        for s1, s2 in zip([0, 2, 2, 4, 4], t):
-            assert is_approx_equal(s1 * msecond, s2) # the firing times are (0,2,2,4,4)ms
-    testwithclock()
-
-    # check multiple spike generator group with generators
-    def st1():
-        yield 0 * msecond
-        yield 2 * msecond
-        yield 4 * msecond
-
-    def st2():
-        yield 1 * msecond
-        yield 3 * msecond
-    spikes = mininet(MultipleSpikeGeneratorGroup, [st1(), st2()])
-    test1(spikes)
-
-    # check reinit
-    spikes1, spikes2 = mininet2(MultipleSpikeGeneratorGroup, [st1, st2])
-    test1(spikes1)
-    test1(spikes2)
-
     # spike generator with list
     spiketimes = [(0, 0 * msecond), (1, 1 * msecond), (0, 2 * msecond), (1, 3 * msecond), (0, 4 * msecond) ]
     spikes = mininet(SpikeGeneratorGroup, 2, spiketimes)
