@@ -10,6 +10,10 @@ __all__ = ['lil_matrix', 'spmatrix']
 
 default = '0_7_1'
 table = {
+    '0.12.0':    '0_7_1',
+    '0.11.0':    '0_7_1',
+    '0.10.1':    '0_7_1',
+    '0.10.0':    '0_7_1',
     '0.9.0':     '0_7_1',
     '0.8.0':     '0_7_1',
     '0.7.2':     '0_7_1',
@@ -33,7 +37,6 @@ else:
             break
     else:
         modulename = default
-        warnings.warn("Couldn't find matching sparse matrix patch for scipy version %s, but in most cases this shouldn't be a problem." % scipy.__version__)
 
 module = __import__(modulename, globals(), locals(), [], -1)
 lil_matrix = module.lil_matrix
