@@ -5,15 +5,19 @@ setup.py module
 
 import os
 import glob
-from setup import version, extras_folders
+
 from zipfile import ZipFile
 
+from brian_setup_info import version, extras_folders
+
+pathname = os.path.abspath(os.path.dirname(__file__))
+os.chdir(pathname)
+os.chdir('../../../.')# work from Brian's root
+
+if not os.path.exists('dist'):
+    os.mkdir('dist')
+
 zipfilename = 'dist/brian-' + version + '-extras.zip'
-
-os.chdir('..')
-os.chdir('..')
-os.chdir('..') # work from Brian's root
-
 files = []
 for folder in extras_folders:
     files.extend(glob.glob(folder))
