@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 '''
 Example of the use of the function spike_triggered_average. A white noise  is filtered
 by a gaussian filter (low pass filter) which output is used to generate spikes (poission process)
@@ -6,6 +7,7 @@ Those spikes are used in conjunction with the input signal to retrieve the filte
 from brian import *
 from brian.hears import *
 from numpy.random import randn
+from numpy.linalg import norm
 from matplotlib import pyplot
 
 dt = 0.1*ms
